package com.usky.dxtop.controller.web;


import com.usky.dxtop.common.annotation.RepeatSubmit;
import com.usky.dxtop.common.constant.UserConstants;
import com.usky.dxtop.common.core.domain.ApiResult;
import com.usky.dxtop.common.core.page.CommonPage;
import com.usky.dxtop.common.exception.CustomException;
import com.usky.dxtop.controller.BaseController;
import com.usky.dxtop.model.Company;
import com.usky.dxtop.service.CompanyService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * 产品信息
 * @author yq
 * @since 2021-09-29
 */
@RestController
@RequestMapping("/dxtop/company")
public class CompanyController extends BaseController {


    @Autowired
    private CompanyService companyService;

    /**
     * 新增
     * @param company
     * @return
     */
    @RepeatSubmit
    @PostMapping
    public ApiResult add(@RequestBody Company company){
        if (UserConstants.NOT_UNIQUE.equals(companyService.checkNameUnique(company)))
        {
            throw new CustomException("新增产品信息'" + company.getName() + "'失败，产品信息已存在");
        }
        return toAjax(companyService.add(company));

    }

    /**
     * 修改
     */
    @PutMapping
    public ApiResult edit(@RequestBody Company company)
    {
        return ApiResult.success(companyService.update(company));
    }

    /**
     * 分页
     * @param current 页数
     * @param size 条数
     * @param name 名称
     * @return
     */
    @GetMapping("/list")
    public ApiResult<CommonPage<Company>> list(@RequestParam Integer current,
                                      @RequestParam Integer size,
                                      @RequestParam(required = false) String name)
    {
        return ApiResult.success(companyService.list(current, size, name));
    }


    /**
     * 删除
     */
    @DeleteMapping("/{id}")
    public ApiResult remove(@PathVariable("id") Long id)
    {
        return toAjax(companyService.remove(id));
    }
}

